@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Open::This;
 
-our $VERSION = '0.000004';
+our $VERSION = '0.000005';
 
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(parse_text to_editor_args);
@@ -68,7 +68,7 @@ sub _module_to_filename {
 }
 
 sub to_editor_args {
-    my $text = shift;
+    my $text = join q{ }, @_;
     return unless $text;
 
     my $found = parse_text($text);
@@ -112,7 +112,12 @@ sub _maybe_extract_subroutine_name {
 sub _maybe_find_local_file {
     my $text          = shift;
     my $possible_name = module_notional_filename($text);
-    for my $dir ( 'lib', 't/lib' ) {
+    my @dirs
+        = exists $ENV{OPEN_THIS_LIBS}
+        ? split m{,}, $ENV{OPEN_THIS_LIBS}
+        : ( 'lib', 't/lib' );
+
+    for my $dir (@dirs) {
         my $path = path( $dir, $possible_name );
         if ( $path->is_file ) {
             return "$path";
@@ -136,27 +141,28 @@ Open::This - Try to Do the Right Thing when opening files
 
 =head1 VERSION
 
-version 0.000004
+version 0.000005
 
 =head1 DESCRIPTION
 
 This module powers the C<ot> command line script, which tries to do the right
-thing when opening a file.  Imagine your C<$EDITOR> %ENV var is set to C<vim>.
-(This should also work for C<emacs> and C<nano>.
+thing when opening a file.  Imagine your C<$ENV{EDITOR}> is set to C<vim>.
+(This should also work for C<emacs> and C<nano>.)  The following examples
+demonstrate how your input is translated when launching your editor.
 
     ot Foo::Bar # vim lib/Foo/Bar.pm
     ot Foo::Bar # vim t/lib/Foo/Bar.pm
 
-Imagine this module has a sub called do_something at line 55.
+Imagine this module has a C<sub do_something> at line 55.
 
     ot "Foo::Bar::do_something()" # vim +55 lib/Foo/Bar.pm
 
-Or, when copy/pasting from a stack trace.  Note that you do not need quotes in
-this case:
+Or, when copy/pasting from a stack trace.  (Note that you do not need quotes in
+this case.)
 
     ot Foo::Bar line 36 # vim +36 lib/Foo/Bar.pm
 
-Copy/pasting a C<git-grep> result:
+Copy/pasting a C<git-grep> result.
 
     ot lib/Foo/Bar.pm:99 # vim +99 Foo/Bar.pm
 
@@ -190,6 +196,10 @@ which can be passed at the command line to an editor.
     my @args = to_editor_args('Foo::Bar::do_something()');
     # @args = ( '+3', 't/lib/Foo/Bar.pm' );
 
+=head1 ENVIRONMENT VARIABLES
+
+By default, C<ot> will search your C<lib> and C<t/lib> directories for local files.  You can override this via the C<$ENV{OPEN_THIS_LIBS}> variable.  It accepts a comma-separated list of libs.
+
 =head1 AUTHOR
 
 Olaf Alders <olaf@wundercounter.com>
